@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-"""Subpackage include models from libraries such as Tensorflow, Statsmodels, Sklearn and some own simple models.
-Various models are included autoregressive model, ARIMA, LSTM, various regressions such as linear or ridge and
-finally some neural units and conjugate gradient. You can use compare_models function to compare models on
-test data. You can see results of all models in interactive plot.
+""" Subpackage include models from libraries such as Tensorflow, Statsmodels, Sklearn and some own simple models.
+Various models are included autoregressive model, ARIMA, LSTM, various regressions such as linear or ridge
+and finally some neural units and conjugate gradient. You can use compare_models function to compare models on test data.
+You can see results of all models in interactive plot.
 
 2 main functions in all models
 
@@ -18,23 +18,17 @@ Models are usually used from `predictit.main`, but it can be use separately as w
 Examples:
 =========
 
-    >>> import mydatapreprocessing as mdp
-    >>> import predictit
-    ...
-    >>> data = mdp.generate_data.sin(1000)
+    >>> data = mdp.generatedata.gen_sin(1000)
     >>> test = data[-7:]
     >>> data = data[: -7]
     >>> data = mdp.preprocessing.data_consolidation(data)
-    >>> (X, y), x_input, _ = mdp.create_model_inputs.create_inputs(
-    ...     data.values, "batch", input_type_params={"n_steps_in": 6}
-    ... )  # First tuple, because some models use raw data, e.g. [1, 2, 3...]
-
-    >>> trained_model = predictit.models.sklearn_regression.train((X, y), model="BayesianRidge")
+    >>> (X, y), x_input, _ = mdp.inputs.create_inputs(data.values, 'batch', input_type_params={'n_steps_in': 6})  # First tuple, because some models use raw data, e.g. [1, 2, 3...]
+    ...
+    >>> trained_model = predictit.models.sklearn_regression.train((X, y), regressor='BayesianRidge')
     >>> predictions_one_model = predictit.models.sklearn_regression.predict(x_input, trained_model, predicts=7)
+    ...
+    >>> predictions_one_model_error = predictit.evaluate_predictions.compare_predicted_to_test(predictions_one_model, test, error_criterion='mape')  # , plot=1
 
-    >>> predictions_one_model_error = predictit.evaluate_predictions.compare_predicted_to_test(
-    ...     predictions_one_model, test, error_criterion="mape"
-    ... )  # , plot=1
 """
 
 from . import models_functions
@@ -84,9 +78,9 @@ models_assignment = {
     **{
         model_name: autoreg_LNU
         for model_name in [
-            "LNU",
-            "LNU normalized",
-            "LNU with weights predicts",
+            "Autoregressive Linear\nneural unit",
+            "Autoregressive Linear\nneural unit normalized",
+            "Linear neural unit\nwith weights predict",
         ]
     },
     **{model_name: regression for model_name in ["Regression", "Ridge regression"]},
