@@ -12,11 +12,11 @@ def train(data, length=50):
     return data.ravel()[-length:].mean()
 
 
-def predict(_, model, predicts=7):
-    """Model that return just arithmetical average from last few data points.
+def predict(data, model, predicts=7):
+    """Model that return just aritmetical average from last few datapoints.
 
     Args:
-        _ (None): Here just fo consistency of positional parameters with other models.
+        data (None): Here just fo consistency with other models.
         model (float): Mean value.
         predicts (int, optional): Number of predicted values. Defaults to 7.
 
